DomRef

Struct DomRef 

pub struct DomRef<'t, 'src: 't> { /* private fields */ }
A lightweight cursor into a Dom, pointing at a single entry by index.

't is the lifetime of the borrow of the tape; 'src is the lifetime of the source JSON bytes ('src: 't). Both lifetimes collapse to the same 'a in the common case where you borrow the tape and the source in the same scope.

Created via Dom::root. Implements crate::JsonRef.

Implementations

Source

impl<'t, 'src: 't> DomRef<'t, 'src>

pub fn object_iter(self) -> Option<DomObjectIter<'t, 'src>>

Returns an iterator over the key-value pairs if this value is a JSON object, or None otherwise.

Example
use asmjson::{parse_to_dom, JsonRef};

let tape = parse_to_dom(r#"{"a":1,"b":2}"#, None).unwrap();
let root = tape.root().unwrap();
for (key, val) in root.object_iter().unwrap() {
    println!("{key}: {}", val.as_number_str().unwrap());
}
pub fn array_iter(self) -> Option<DomArrayIter<'t, 'src>>

Returns an iterator over the elements if this value is a JSON array, or None otherwise.

Example
use asmjson::{parse_to_dom, JsonRef};

let tape = parse_to_dom(r#"[1,2,3]"#, None).unwrap();
let root = tape.root().unwrap();
for elem in root.array_iter().unwrap() {
    println!("{}", elem.as_number_str().unwrap());
}